@@ -53,7 +53,7 @@ def main():
 
         backup_path = get_config_option(config, 'general', 'backup_path', fallback=backup_path)
         token = get_config_option(config, 'general', 'dropbox_token', fallback=token)
-        mysql = get_config_option(config, 'general', 'mysql', fallback=mysql)
+        mysql = get_config_option(config, 'general', 'mysql', boolean=True, fallback=mysql)
         packs = get_config_option(config, 'backup_packs', fallback=packs)
 
     if token is None or packs is None:
@@ -81,12 +81,13 @@ class BackupManager(object):
             file_name = "%s.tar.gz" % name
             if name and path:
                 print "\tmaking pack for %s..." % path
-                os.system('sudo tar -c %s 2> /dev/null | gzip -n9 > %s' % (path, os.path.join(self.backup_path, file_name)))
+                os.system('sudo tar -c %s 2> /dev/null | gzip -fn9 > %s' % (path, os.path.join(self.backup_path, file_name)))
 
         if self.mysql:
             file_name = "mysql.sql"
-            os.system('mysqldump --all-databases 2> /dev/null > %s' % os.path.join('/tmp', file_name))
-            os.system('gzip -n9 %s > %s' % (os.path.join('/tmp', file_name), os.path.join(self.backup_path, "%s.gz" % file_name)))
+            print "\tmaking pack for mysql..."
+            os.system('mysqldump -uroot --all-databases 2> /dev/null > %s' % os.path.join('/tmp', file_name))
+            os.system('gzip -cfn9 %s > %s' % (os.path.join('/tmp', file_name), os.path.join(self.backup_path, "%s.gz" % file_name)))
 
 class DropboxUploader(object):
     def __init__(self, backup_path, token):
