@@ -1,11 +1,7 @@
 BACKUP_PATH = "/home/backups/"
 MYSQL_BACKUP = True
 
-BACKUP_PACKS = [
-    "git:/home/git/",
-    "nginx:/etc/nginx/",
-    "minecraft:/home/minecraft",
-]
+CONF_FILE = "/etc/dropbox_backup.conf"
 
 CHUNK_SIZE = 1024 * 10000
 DROPBOX_BASE_URL = "https://api.dropbox.com/1"
